@@ -47,9 +47,7 @@ class WebHDFSHook(BaseHook):
     Interact with HDFS. This class is a wrapper around the hdfscli library.
 
     :param webhdfs_conn_id: The connection id for the webhdfs client to connect to.
-    :type webhdfs_conn_id: str
     :param proxy_user: The user used to authenticate.
-    :type proxy_user: str
     """
 
     def __init__(self, webhdfs_conn_id: str = 'webhdfs_default', proxy_user: Optional[str] = None):
@@ -112,7 +110,6 @@ class WebHDFSHook(BaseHook):
         Check for the existence of a path in HDFS by querying FileStatus.
 
         :param hdfs_path: The path to check.
-        :type hdfs_path: str
         :return: True if the path exists and False if not.
         :rtype: bool
         """
@@ -131,15 +128,11 @@ class WebHDFSHook(BaseHook):
             If it's a folder, all the files inside of it will be uploaded.
             .. note:: This implies that folders empty of files will not be created remotely.
 
-        :type source: str
         :param destination: PTarget HDFS path.
             If it already exists and is a directory, files will be uploaded inside.
-        :type destination: str
         :param overwrite: Overwrite any existing file or directory.
-        :type overwrite: bool
         :param parallelism: Number of threads to use for parallelization.
             A value of `0` (or negative) uses as many threads as there are files.
-        :type parallelism: int
         :param kwargs: Keyword arguments forwarded to :meth:`hdfs.client.Client.upload`.
         """
         conn = self.get_conn()
